Concept Encoders
=====================

This module provides encoder implementations that transform input features into concept representations.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Encoder Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   LinearZC
   LinearUC
   StochasticZC
   LinearZU
   SelectorZU


Class Documentation
-------------------

.. autoclass:: LinearZC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: LinearUC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: StochasticZC
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: LinearZU
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: SelectorZU
   :members:
   :undoc-members:
   :show-inheritance:
